@@ -5,4 +5,4 @@ class TFA:
         self.access_token = access_token
 
     def authUser(self, user_token):
-        return req.get(f'https://tele-fa-api.herokuapp.com/api/access/{self.access_token}/{user_token}').json()
\ No newline at end of file
+        return req.get(f'https://tele-fa-api.herokuapp.com/api/access/{self.access_token}/{user_token}')
\ No newline at end of file
